import random


class SimpleTable:
    def __init__(self, table_name, table_values = None):
        self.table_name = table_name

        if table_values is not None:
            if isinstance(table_values, list):
                self.table_values = table_values
            else:
                self.table_values = []
        else:
            self.table_values = []

    def add_value(self, table_value):
        self.table_values.append(table_value)

    def get_value(self):
        random.shuffle(self.table_values)
        return self.table_values[0]


if __name__ == '__main__':
    test = SimpleTable("foo", ["bar", "baz"])
    print(test.get_value())



import re


class Parser:
    def __init__(self, pychance_instance):
        self.pychance_instance = pychance_instance
        self.simple_list_pattern = re.compile(r"(\[(?P<list>[a-zA-Z_][a-zA-Z0-9_]+?)\])")

    def parse(self, message):
        match = self.simple_list_pattern.search(message)
        while match is not None:
            which_list = match.group('list')

            if which_list in self.pychance_instance.tables:
                message = self.simple_list_pattern.sub(self.pychance_instance.tables[which_list].get_value(), message)
            else:
                message = self.simple_list_pattern.sub('undefined', message)

            match = self.simple_list_pattern.search(message)

        return message



import threading


class SingletonMixin(object):
    __singleton_lock = threading.Lock()
    __singleton_instance = None

    @classmethod
    def instance(cls, *args, **kwargs):
        if not cls.__singleton_instance:
            with cls.__singleton_lock:
                if not cls.__singleton_instance:
                    cls.__singleton_instance = cls(*args, **kwargs)
        return cls.__singleton_instance
